@@ -8,6 +8,7 @@ use Capture::Tiny 'capture';
 use Carp;
 use DBI;
 use File::Temp;
+use Log::Any;
 use Scope::Guard qw(guard);
 
 use Moo;
@@ -20,11 +21,11 @@ PGObject
 
 =head1 VERSION
 
-version 1.3.0
+version 1.5.0
 
 =cut
 
-our $VERSION = '1.3.0';
+our $VERSION = '1.5.0';
 
 
 =head1 SYNOPSIS
@@ -207,6 +208,23 @@ notes in L</"CAPTURING">.
 
 has stdout => (is => 'ro');
 
+=head2 logger
+
+Provides a reference to the logger associated with the current instance. The
+logger uses C<ref $self> as its category, eliminating the need to create
+new loggers when deriving from this class.
+
+If you want to override the logger-instantiation behaviour, please implement
+the C<_build_logger> builder method in your derived class.
+
+=cut
+
+has logger => (is => 'ro', lazy => 1, builder => '_build_logger');
+
+sub _build_logger {
+    return Log::Any->get_logger(category => ref $_[0]);
+}
+
 
 our %helpers =
     (
@@ -277,6 +295,11 @@ sub _run_command {
         # overruled by highest priority: specified environment
         ($args{env}   ? %{$args{env}} : ()),
         );
+    $self->logger->debugf(
+        sub {
+            return 'Running with environment: '
+                . join(' ', map { qq|$_="$env{$_}"| } keys %env );
+        });
 
     # Any files created should be accessible only by the current user
     my $original_umask = umask 0077;
@@ -520,11 +543,17 @@ sub server_version {
     my $self = shift @_;
     my $dbname = (shift @_) || 'template1';
     my $version =
-           __PACKAGE__->new($self->export, (dbname => $dbname)
-                           )->connect->selectrow_array('SELECT version()');
-    my ($retval) = $version =~ /(\d+\.\d+\.\d+)/
-        or croak 'failed to extract version string';
-    return $retval;
+        __PACKAGE__->new($self->export, (dbname => $dbname)
+        )->connect->{pg_server_version};
+
+    my $retval = '';
+    while (1) {
+        $retval = ($version % 100) . $retval;
+        $version = int($version / 100);
+
+        return $retval unless $version;
+        $retval = ".$retval";
+    }
 }
 
 
